(function (global, factory) {
	typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core')) :
	typeof define === 'function' && define.amd ? define(['exports', '@angular/core'], factory) :
	(factory((global.ngx = global.ngx || {}, global.ngx.dragdrop = global.ngx.dragdrop || {}),global.ng.core));
}(this, (function (exports,_angular_core) { 'use strict';

/* Copyright VMware, Inc. All rights reserved. VMware Confidential */
var NgxDragDropService = (function () {
    function NgxDragDropService() {
        this.defaultInstanceName = 'ngx-dragdrop';
        this.setDefaultInstance();
    }
    Object.defineProperty(NgxDragDropService.prototype, "instanceName", {
        get: function () {
            return this.name;
        },
        set: function (name) {
            this.name = name;
        },
        enumerable: true,
        configurable: true
    });
    NgxDragDropService.prototype.setDefaultInstance = function () {
        this.name = this.defaultInstanceName;
    };
    NgxDragDropService.prototype.isDefaultInstance = function () {
        return this.name === this.defaultInstanceName;
    };
    NgxDragDropService.decorators = [
        { type: _angular_core.Injectable } ];
    /** @nocollapse */
    NgxDragDropService.ctorParameters = function () { return []; };
    return NgxDragDropService;
}());

/* Copyright VMware, Inc. All rights reserved. VMware Confidential */
var NgxDraggableDirective = (function () {
    function NgxDraggableDirective(el, dragDropService) {
        this.el = el;
        this.dragDropService = dragDropService;
        this._isDraggable = false;
    }
    Object.defineProperty(NgxDraggableDirective.prototype, "isDraggable", {
        get: function () {
            return this._isDraggable;
        },
        set: function (dragEnabled) {
            this.el.nativeElement.setAttribute('draggable', dragEnabled);
            this._isDraggable = dragEnabled;
        },
        enumerable: true,
        configurable: true
    });
    NgxDraggableDirective.prototype.onDragStart = function (event) {
        if (this.el.nativeElement === event.target) {
            event.target.classList.add(this.draggedClass);
            event.dataTransfer.setData('data', JSON.stringify({ dd: this.dragData }));
            if (this.dragTag) {
                this.dragDropService.instanceName = this.dragTag;
            }
            else {
                this.dragDropService.setDefaultInstance();
            }
        }
    };
    NgxDraggableDirective.prototype.onDragEnd = function (event) {
        if (this.el.nativeElement === event.target) {
            event.target.classList.remove(this.draggedClass);
        }
    };
    NgxDraggableDirective.decorators = [
        { type: _angular_core.Directive, args: [{
                    selector: '[ngx-draggable]'
                } ] } ];
    /** @nocollapse */
    NgxDraggableDirective.ctorParameters = function () { return [
        { type: _angular_core.ElementRef, },
        { type: NgxDragDropService, } ]; };
    NgxDraggableDirective.propDecorators = {
        'isDraggable': [{ type: _angular_core.Input, args: ['ngx-draggable' ] } ],
        'dragTag': [{ type: _angular_core.Input, args: ['ngx-dragTag' ] } ],
        'draggedClass': [{ type: _angular_core.Input, args: ['ngx-draggedClass' ] } ],
        'dragData': [{ type: _angular_core.Input, args: ['ngx-dragData' ] } ],
        'onDragStart': [{ type: _angular_core.HostListener, args: ['dragstart', ['$event'] ] } ],
        'onDragEnd': [{ type: _angular_core.HostListener, args: ['dragend', ['$event'] ] } ],
    };
    return NgxDraggableDirective;
}());

/* Copyright VMware, Inc. All rights reserved. VMware Confidential */
var NgxDroppableDirective = (function () {
    function NgxDroppableDirective(el, dragDropService) {
        this.el = el;
        this.dragDropService = dragDropService;
        this.onDropData = new _angular_core.EventEmitter();
        this.dropTags = [this.dragDropService.instanceName];
    }
    NgxDroppableDirective.prototype.onDragEnter = function (event) {
        if (event.preventDefault) {
            event.preventDefault();
        }
        if (event.stopPropagation) {
            event.stopPropagation();
        }
        if (this.el.nativeElement === event.target) {
            if (this.dropTags.indexOf(this.dragDropService.instanceName) !== -1) {
                event.target.classList.add(this.dragDropService.instanceName);
            }
        }
    };
    NgxDroppableDirective.prototype.onDragOver = function (event) {
        if (event.preventDefault) {
            event.preventDefault();
        }
        if (event.stopPropagation) {
            event.stopPropagation();
        }
        if (this.el.nativeElement === event.target) {
            if (this.dropTags.indexOf(this.dragDropService.instanceName) !== -1) {
                event.dataTransfer.effectAllowed = 'all';
                event.dataTransfer.dropEffect = 'move';
            }
            else {
                event.dataTransfer.effectAllowed = 'none';
                event.dataTransfer.dropEffect = 'none';
            }
        }
    };
    NgxDroppableDirective.prototype.onDragLeave = function (event) {
        if (event.preventDefault) {
            event.preventDefault();
        }
        if (event.stopPropagation) {
            event.stopPropagation();
        }
        if (this.el.nativeElement === event.target) {
            if (this.dropTags.indexOf(this.dragDropService.instanceName) !== -1) {
                event.target.classList.remove(this.dragDropService.instanceName);
            }
        }
    };
    NgxDroppableDirective.prototype.onDrop = function (event) {
        if (event.preventDefault) {
            event.preventDefault();
        }
        if (event.stopPropagation) {
            event.stopPropagation();
        }
        if (this.el.nativeElement === event.target) {
            var dragTag = this.dragDropService.instanceName;
            var data = event.dataTransfer.getData('data');
            var dragData = void 0;
            try {
                dragData = JSON.parse(data).dd;
                if (this.dropTags.indexOf(this.dragDropService.instanceName) !== -1) {
                    event.target.classList.remove(this.dragDropService.instanceName);
                    this.onDropData.emit({ dragTag: dragTag, dragData: dragData, dropData: this.dropData });
                }
            }
            catch (e) {
                if (console && typeof console.log === 'function') {
                    console.log(e);
                    console.log('Drop failed! Data: ', data);
                }
            }
        }
    };
    NgxDroppableDirective.decorators = [
        { type: _angular_core.Directive, args: [{
                    selector: '[ngx-droppable]'
                } ] } ];
    /** @nocollapse */
    NgxDroppableDirective.ctorParameters = function () { return [
        { type: _angular_core.ElementRef, },
        { type: NgxDragDropService, } ]; };
    NgxDroppableDirective.propDecorators = {
        'onDropData': [{ type: _angular_core.Output, args: ['ngx-droppable' ] } ],
        'dropTags': [{ type: _angular_core.Input, args: ['ngx-dropTags' ] } ],
        'dropData': [{ type: _angular_core.Input, args: ['ngx-dropData' ] } ],
        'onDragEnter': [{ type: _angular_core.HostListener, args: ['dragenter', ['$event'] ] } ],
        'onDragOver': [{ type: _angular_core.HostListener, args: ['dragover', ['$event'] ] } ],
        'onDragLeave': [{ type: _angular_core.HostListener, args: ['dragleave', ['$event'] ] } ],
        'onDrop': [{ type: _angular_core.HostListener, args: ['drop', ['$event'] ] } ],
    };
    return NgxDroppableDirective;
}());

/* Copyright VMware, Inc. All rights reserved. VMware Confidential */
var NgxDragDropModule = (function () {
    function NgxDragDropModule() {
    }
    NgxDragDropModule.forRoot = function () {
        return {
            ngModule: NgxDragDropModule,
            providers: []
        };
    };
    NgxDragDropModule.forChild = function () {
        return {
            ngModule: NgxDragDropModule,
            providers: []
        };
    };
    NgxDragDropModule.decorators = [
        { type: _angular_core.NgModule, args: [{
                    declarations: [
                        NgxDraggableDirective,
                        NgxDroppableDirective
                    ],
                    providers: [NgxDragDropService],
                    exports: [NgxDraggableDirective, NgxDroppableDirective]
                } ] } ];
    /** @nocollapse */
    NgxDragDropModule.ctorParameters = function () { return []; };
    return NgxDragDropModule;
}());

/* Copyright VMware, Inc. All rights reserved. VMware Confidential */

exports.NgxDragDropModule = NgxDragDropModule;

Object.defineProperty(exports, '__esModule', { value: true });

})));
