/* Copyright VMware, Inc. All rights reserved. VMware Confidential */
import { Directive, ElementRef, Input, HostListener } from "@angular/core";
import { NgxDragDropService } from "./dragDrop.service";
var NgxDraggableDirective = (function () {
    function NgxDraggableDirective(el, dragDropService) {
        this.el = el;
        this.dragDropService = dragDropService;
        this._isDraggable = false;
    }
    Object.defineProperty(NgxDraggableDirective.prototype, "isDraggable", {
        get: function () {
            return this._isDraggable;
        },
        set: function (dragEnabled) {
            this.el.nativeElement.setAttribute('draggable', dragEnabled);
            this._isDraggable = dragEnabled;
        },
        enumerable: true,
        configurable: true
    });
    NgxDraggableDirective.prototype.onDragStart = function (event) {
        if (this.el.nativeElement === event.target) {
            event.target.classList.add(this.draggedClass);
            event.dataTransfer.setData('data', JSON.stringify({ dd: this.dragData }));
            if (this.dragTag) {
                this.dragDropService.instanceName = this.dragTag;
            }
            else {
                this.dragDropService.setDefaultInstance();
            }
        }
    };
    NgxDraggableDirective.prototype.onDragEnd = function (event) {
        if (this.el.nativeElement === event.target) {
            event.target.classList.remove(this.draggedClass);
        }
    };
    NgxDraggableDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[ngx-draggable]'
                },] },
    ];
    /** @nocollapse */
    NgxDraggableDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: NgxDragDropService, },
    ]; };
    NgxDraggableDirective.propDecorators = {
        'isDraggable': [{ type: Input, args: ['ngx-draggable',] },],
        'dragTag': [{ type: Input, args: ['ngx-dragTag',] },],
        'draggedClass': [{ type: Input, args: ['ngx-draggedClass',] },],
        'dragData': [{ type: Input, args: ['ngx-dragData',] },],
        'onDragStart': [{ type: HostListener, args: ['dragstart', ['$event'],] },],
        'onDragEnd': [{ type: HostListener, args: ['dragend', ['$event'],] },],
    };
    return NgxDraggableDirective;
}());
export { NgxDraggableDirective };
//# sourceMappingURL=draggable.directive.js.map