/* Copyright VMware, Inc. All rights reserved. VMware Confidential */
import { Directive, ElementRef, Input, HostListener, Output, EventEmitter } from "@angular/core";
import { NgxDragDropService } from "./dragDrop.service";
var NgxDroppableDirective = (function () {
    function NgxDroppableDirective(el, dragDropService) {
        this.el = el;
        this.dragDropService = dragDropService;
        this.onDropData = new EventEmitter();
        this.dropTags = [this.dragDropService.instanceName];
    }
    NgxDroppableDirective.prototype.onDragEnter = function (event) {
        if (event.preventDefault) {
            event.preventDefault();
        }
        if (event.stopPropagation) {
            event.stopPropagation();
        }
        if (this.el.nativeElement === event.target) {
            if (this.dropTags.indexOf(this.dragDropService.instanceName) !== -1) {
                event.target.classList.add(this.dragDropService.instanceName);
            }
        }
    };
    NgxDroppableDirective.prototype.onDragOver = function (event) {
        if (event.preventDefault) {
            event.preventDefault();
        }
        if (event.stopPropagation) {
            event.stopPropagation();
        }
        if (this.el.nativeElement === event.target) {
            if (this.dropTags.indexOf(this.dragDropService.instanceName) !== -1) {
                event.dataTransfer.effectAllowed = 'all';
                event.dataTransfer.dropEffect = 'move';
            }
            else {
                event.dataTransfer.effectAllowed = 'none';
                event.dataTransfer.dropEffect = 'none';
            }
        }
    };
    NgxDroppableDirective.prototype.onDragLeave = function (event) {
        if (event.preventDefault) {
            event.preventDefault();
        }
        if (event.stopPropagation) {
            event.stopPropagation();
        }
        if (this.el.nativeElement === event.target) {
            if (this.dropTags.indexOf(this.dragDropService.instanceName) !== -1) {
                event.target.classList.remove(this.dragDropService.instanceName);
            }
        }
    };
    NgxDroppableDirective.prototype.onDrop = function (event) {
        if (event.preventDefault) {
            event.preventDefault();
        }
        if (event.stopPropagation) {
            event.stopPropagation();
        }
        if (this.el.nativeElement === event.target) {
            var dragTag = this.dragDropService.instanceName;
            var data = event.dataTransfer.getData('data');
            var dragData = void 0;
            try {
                dragData = JSON.parse(data).dd;
                if (this.dropTags.indexOf(this.dragDropService.instanceName) !== -1) {
                    event.target.classList.remove(this.dragDropService.instanceName);
                    this.onDropData.emit({ dragTag: dragTag, dragData: dragData, dropData: this.dropData });
                }
            }
            catch (e) {
                if (console && typeof console.log === 'function') {
                    console.log(e);
                    console.log('Drop failed! Data: ', data);
                }
            }
        }
    };
    NgxDroppableDirective.decorators = [
        { type: Directive, args: [{
                    selector: '[ngx-droppable]'
                },] },
    ];
    /** @nocollapse */
    NgxDroppableDirective.ctorParameters = function () { return [
        { type: ElementRef, },
        { type: NgxDragDropService, },
    ]; };
    NgxDroppableDirective.propDecorators = {
        'onDropData': [{ type: Output, args: ['ngx-droppable',] },],
        'dropTags': [{ type: Input, args: ['ngx-dropTags',] },],
        'dropData': [{ type: Input, args: ['ngx-dropData',] },],
        'onDragEnter': [{ type: HostListener, args: ['dragenter', ['$event'],] },],
        'onDragOver': [{ type: HostListener, args: ['dragover', ['$event'],] },],
        'onDragLeave': [{ type: HostListener, args: ['dragleave', ['$event'],] },],
        'onDrop': [{ type: HostListener, args: ['drop', ['$event'],] },],
    };
    return NgxDroppableDirective;
}());
export { NgxDroppableDirective };
//# sourceMappingURL=droppable.directive.js.map